@@ -237,6 +237,8 @@ def fit_KPFM_curve(VG: list, phit: list, t: float, Cox: float, p0=[1,1,1]) -> np
 
     """
     
+    p0 = p0.append(t)
+    p0=p0.append(Cox)
     start_time = time.time() #start time counting
     
     #Fit data setting to completely bounded parameters t and Cox since they
